Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(775)

Unified Diff: chrome/browser/ui/webui/settings/settings_manage_profile_handler.h

Issue 2525783002: MD Settings: Hide Profile Shortcut switch for single-profile machines. (Closed)
Patch Set: one more fix to make it actually work Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/webui/settings/settings_manage_profile_handler.h
diff --git a/chrome/browser/ui/webui/settings/settings_manage_profile_handler.h b/chrome/browser/ui/webui/settings/settings_manage_profile_handler.h
index ad1046b965b9d2fcdf40d79095296aaa655b875c..d39d57880356fe640404cd6da805eab8fdad82c6 100644
--- a/chrome/browser/ui/webui/settings/settings_manage_profile_handler.h
+++ b/chrome/browser/ui/webui/settings/settings_manage_profile_handler.h
@@ -56,10 +56,10 @@ class ManageProfileHandler : public settings::SettingsPageUIHandler,
// ]
void HandleSetProfileIconAndName(const base::ListValue* args);
// Callback for the "requestHasProfileShortcuts" message, which is called
// when editing an existing profile. Asks the profile shortcut manager whether
// the profile has shortcuts and gets the result in |OnHasProfileShortcuts()|.
- void HandleRequestHasProfileShortcuts(const base::ListValue* args);
+ void HandleRequestProfileShortcutStatus(const base::ListValue* args);
// Callback invoked from the profile manager indicating whether the profile
// being edited has any desktop shortcuts.
@@ -56,10 +56,10 @@ class ManageProfileHandler : public settings::SettingsPageUIHandler,
// ]
void HandleSetProfileIconAndName(const base::ListValue* args);
- // Callback for the "requestHasProfileShortcuts" message, which is called
+ // Callback for the "requestProfileShortcutStatus" message, which is called
// when editing an existing profile. Asks the profile shortcut manager whether
// the profile has shortcuts and gets the result in |OnHasProfileShortcuts()|.

Powered by Google App Engine
This is Rietveld 408576698